@@ -1,7 +1,7 @@
 package Finance::CoinbasePro::Lite;
 
 our $DATE = '2018-11-29'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -155,7 +155,7 @@ Finance::CoinbasePro::Lite - Client API library for Coinbase Pro (lite edition)
 
 =head1 VERSION
 
-This document describes version 0.003 of Finance::CoinbasePro::Lite (from Perl distribution Finance-CoinbasePro-Lite), released on 2018-11-29.
+This document describes version 0.004 of Finance::CoinbasePro::Lite (from Perl distribution Finance-CoinbasePro-Lite), released on 2018-11-29.
 
 =head1 SYNOPSIS
 
@@ -259,6 +259,11 @@ feature.
 
 Coinbase Pro API Reference, L<https://docs.pro.coinbase.com/>
 
+L<Finance::GDAX::API>
+
+CLI's: L<Finance::CoinbasePro::API::CLI>, L<coinbasepro-lite> from
+L<App::coinbase::lite>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
